@@ -1,7 +1,8 @@
 from pykechain.exceptions import _DeprecationMixin
+from pykechain.models import ActivityReferencesProperty
 
 
-class ActivityReferencesProperty(_DeprecationMixin):
+class ActivityReferencesProperty2(ActivityReferencesProperty, _DeprecationMixin):
     """A virtual object representing a KE-chain Activity References property.
 
     .. versionadded:: 3.7
